#!/bin/sh
AWK=$1

cat > symbols.cc <<EOT
#include <glib.h>
#include "symbols.h"

GData *get_symbols()
{
	GData *datalist;
	g_datalist_init (&datalist);
EOT

for i in command*.cc
do
    $AWK -f symbols.cc.awk $i >> symbols.cc
done

for i in variable*.cc
do
    $AWK -f symbols.cc.awk $i >> symbols.cc
done

for i in symbol*.cc
do
	if [ $i != symbols.cc ] ; then
        	$AWK -f symbols.cc.awk $i >> symbols.cc
	fi
done

cat >> symbols.cc <<EOT
	return datalist;
}
EOT
